==> gi-assets-algorithm-2.3.9.tgz: package/es/NodeImportance/resultTable.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useContext } from '@antv/gi-sdk';
import { Select, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import { ITEM_STATE, MappingWay } from './registerMeta';
import $i18n from '../i18n';
var ResultTable = function ResultTable(_ref) {
  var data = _ref.data,
    currentAlgo = _ref.currentAlgo,
    form = _ref.form,
    reAnalyse = _ref.reAnalyse,
    nodeProperties = _ref.nodeProperties;
  var _useContext = useContext(),
    graph = _useContext.graph;
  var formValues = form.getFieldsValue();
  var edgeType = formValues['edge-property.edgeType'];
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    sortOrder = _useState2[0],
    setSortOrder = _useState2[1];
  var _useState3 = useState('id'),
    _useState4 = _slicedToArray(_useState3, 2),
    propertyKey = _useState4[0],
    setPropertyKey = _useState4[1];
  useEffect(function () {
    setSortOrder(false);
  }, [reAnalyse]);
  var getResultColumns = function getResultColumns() {
    var columns = [{
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.SerialNumber',
        dm: '序号'
      }),
      dataIndex: 'index',
      key: 'index',
      width: 60
    }, {
      title: (nodeProperties === null || nodeProperties === void 0 ? void 0 : nodeProperties.length) ? /*#__PURE__*/React.createElement(React.Fragment, null, $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Node',
        dm: '节点'
      }), /*#__PURE__*/React.createElement(Select, {
        className: "result-table-property-select",
        size: "small",
        defaultValue: "id",
        options: nodeProperties.map(function (key) {
          return {
            label: key,
            value: key
          };
        }),
        dropdownMatchSelectWidth: false,
        onChange: setPropertyKey
      })) : $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Node',
        dm: '节点'
      }),
      dataIndex: 'name',
      key: 'name',
      textWrap: 'word-break',
      ellipsis: true
    }, {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Importance',
        dm: '重要性'
      }),
      dataIndex: 'value',
      key: 'value',
      textWrap: 'word-break',
      sortOrder: sortOrder,
      sorter: function sorter(a, b) {
        return a.value - b.value;
      }
    }];
    if (currentAlgo === 'edge-property' && data.calcWay === 'count') {
      //@ts-ignore
      columns.splice(2, 0, {
        title: $i18n.get({
          id: 'gi-assets-algorithm.src.NodeImportance.resultTable.AttributeName',
          dm: '属性名'
        }),
        dataIndex: 'values',
        key: 'values',
        textWrap: 'word-break'
      });
      columns[3].title = $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.CalculationMethod',
        dm: '计算方式'
      });
    }
    return columns;
  };
  var getResultTableData = function getResultTableData() {
    var nodes = _toConsumableArray(data.node.data);
    if (data.mappingWay === MappingWay.Negative) {
      nodes.reverse();
    }
    return nodes.map(function (node, index) {
      var _a;
      return {
        key: node.id,
        index: index + 1,
        name: node.originProperties[propertyKey] || node.id,
        value: node.value,
        values: (_a = node.values) === null || _a === void 0 ? void 0 : _a.join('; ')
      };
    });
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', ITEM_STATE.Active).concat(graph.findAllByState('edge', ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, ITEM_STATE.Active, false);
    });
  };
  var onEnterTableRow = function onEnterTableRow(record) {
    var _a, _b;
    clearActiveItems();
    var item = graph.findById(record.key);
    if (!item) {
      return;
    }
    graph.setItemState(item, ITEM_STATE.Active, true);
    // 若为关系属性重要性, 同时高亮该节点相关的被映射过的边
    if (currentAlgo === 'edge-property') {
      (_b = (_a = data.edge) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.forEach(function (edge) {
        var edgeItem = graph.findById(edge.id);
        if (!edgeItem) {
          return;
        }
        var edgeModel = edgeItem.getModel();
        //@ts-ignore
        if (edgeModel.data.label !== (edgeType === null || edgeType === void 0 ? void 0 : edgeType.split('_')[1])) {
          return;
        }
        if (edgeModel.source === record.key || edgeModel.target === record.id) {
          graph.setItemState(edgeItem, ITEM_STATE.Active, true);
        }
      });
    }
  };
  var onTableChange = function onTableChange(pagination, filters, sorter, extra) {
    if (extra.action === 'sort') {
      setSortOrder(sorter.order || false);
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    className: "result-wrapper"
  }, /*#__PURE__*/React.createElement(Table, {
    dataSource: getResultTableData(),
    //@ts-ignore
    columns: getResultColumns(),
    size: "small",
    style: {
      marginTop: '16px'
    },
    showSorterTooltip: {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Sort',
        dm: '排序'
      })
    },
    onRow: function onRow(record) {
      return {
        onMouseEnter: function onMouseEnter() {
          return onEnterTableRow(record);
        },
        onMouseLeave: clearActiveItems
      };
    },
    onChange: onTableChange
  }));
};
export default ResultTable;

==> gi-assets-algorithm-2.3.16.tgz: package/es/NodeImportance/resultTable.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useContext } from '@antv/gi-sdk';
import { Select, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import { ITEM_STATE, MappingWay } from './registerMeta';
import $i18n from '../i18n';
var ResultTable = function ResultTable(_ref) {
  var data = _ref.data,
    currentAlgo = _ref.currentAlgo,
    form = _ref.form,
    reAnalyse = _ref.reAnalyse,
    nodeProperties = _ref.nodeProperties;
  var _useContext = useContext(),
    graph = _useContext.graph;
  var formValues = form.getFieldsValue();
  var edgeType = formValues['edge-property.edgeType'];
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    sortOrder = _useState2[0],
    setSortOrder = _useState2[1];
  var _useState3 = useState('id'),
    _useState4 = _slicedToArray(_useState3, 2),
    propertyKey = _useState4[0],
    setPropertyKey = _useState4[1];
  useEffect(function () {
    setSortOrder(false);
  }, [reAnalyse]);
  var getResultColumns = function getResultColumns() {
    var columns = [{
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.SerialNumber',
        dm: '序号'
      }),
      dataIndex: 'index',
      key: 'index',
      width: 60
    }, {
      title: (nodeProperties === null || nodeProperties === void 0 ? void 0 : nodeProperties.length) ? /*#__PURE__*/React.createElement(React.Fragment, null, $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Node',
        dm: '节点'
      }), /*#__PURE__*/React.createElement(Select, {
        className: "result-table-property-select",
        size: "small",
        defaultValue: "id",
        options: nodeProperties.map(function (key) {
          return {
            label: key,
            value: key
          };
        }),
        dropdownMatchSelectWidth: false,
        onChange: setPropertyKey
      })) : $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Node',
        dm: '节点'
      }),
      dataIndex: 'name',
      key: 'name',
      textWrap: 'word-break',
      ellipsis: true
    }, {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Importance',
        dm: '重要性'
      }),
      dataIndex: 'value',
      key: 'value',
      textWrap: 'word-break',
      sortOrder: sortOrder,
      sorter: function sorter(a, b) {
        return a.value - b.value;
      }
    }];
    if (currentAlgo === 'edge-property' && data.calcWay === 'count') {
      //@ts-ignore
      columns.splice(2, 0, {
        title: $i18n.get({
          id: 'gi-assets-algorithm.src.NodeImportance.resultTable.AttributeName',
          dm: '属性名'
        }),
        dataIndex: 'values',
        key: 'values',
        textWrap: 'word-break'
      });
      columns[3].title = $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.CalculationMethod',
        dm: '计算方式'
      });
    }
    return columns;
  };
  var getResultTableData = function getResultTableData() {
    var nodes = _toConsumableArray(data.node.data);
    if (data.mappingWay === MappingWay.Negative) {
      nodes.reverse();
    }
    return nodes.map(function (node, index) {
      var _a;
      return {
        key: node.id,
        index: index + 1,
        name: node.originProperties[propertyKey] || node.id,
        value: node.value,
        values: (_a = node.values) === null || _a === void 0 ? void 0 : _a.join('; ')
      };
    });
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', ITEM_STATE.Active).concat(graph.findAllByState('edge', ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, ITEM_STATE.Active, false);
    });
  };
  var onEnterTableRow = function onEnterTableRow(record) {
    var _a, _b;
    clearActiveItems();
    var item = graph.findById(record.key);
    if (!item) {
      return;
    }
    graph.setItemState(item, ITEM_STATE.Active, true);
    // 若为关系属性重要性, 同时高亮该节点相关的被映射过的边
    if (currentAlgo === 'edge-property') {
      (_b = (_a = data.edge) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.forEach(function (edge) {
        var edgeItem = graph.findById(edge.id);
        if (!edgeItem) {
          return;
        }
        var edgeModel = edgeItem.getModel();
        //@ts-ignore
        if (edgeModel.data.label !== (edgeType === null || edgeType === void 0 ? void 0 : edgeType.split('_')[1])) {
          return;
        }
        if (edgeModel.source === record.key || edgeModel.target === record.id) {
          graph.setItemState(edgeItem, ITEM_STATE.Active, true);
        }
      });
    }
  };
  var onTableChange = function onTableChange(pagination, filters, sorter, extra) {
    if (extra.action === 'sort') {
      setSortOrder(sorter.order || false);
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    className: "result-wrapper"
  }, /*#__PURE__*/React.createElement(Table, {
    dataSource: getResultTableData(),
    //@ts-ignore
    columns: getResultColumns(),
    size: "small",
    style: {
      marginTop: '16px'
    },
    showSorterTooltip: {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.NodeImportance.resultTable.Sort',
        dm: '排序'
      })
    },
    onRow: function onRow(record) {
      return {
        onMouseEnter: function onMouseEnter() {
          return onEnterTableRow(record);
        },
        onMouseLeave: clearActiveItems
      };
    },
    onChange: onTableChange
  }));
};
export default ResultTable;
